Install and Uninstall BuildingsPy — BuildingsPy documentation

### Navigation

- index
- modules |
- next |
- previous |
- Home > BuildingsPy

# Install and Uninstall BuildingsPy

To install the buildingspy module, install pip and run from a console

    pip install buildingspy

On Linux or Mac OS X, run

    sudo pip install buildingspy

To uninstall, run

    pip uninstall buildingspy

On Linux or Mac OS X, run

    sudo pip uninstall buildingspy

### Navigation

- index
- modules |
- next |
- previous |
- Home > BuildingsPy